summaryrefslogtreecommitdiffstats
path: root/src/kicondialog.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:29:20 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:29:20 -0600
commit882bcd26b3d60be72ea2b35921969a9850c52db9 (patch)
tree8d0a6902c5de4632c4e73e35c4d86404fa75f470 /src/kicondialog.cpp
parentc82058b2b64334c10d7e547cb81ac64efe09f516 (diff)
downloadbasket-882bcd26b3d60be72ea2b35921969a9850c52db9.tar.gz
basket-882bcd26b3d60be72ea2b35921969a9850c52db9.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'src/kicondialog.cpp')
-rw-r--r--src/kicondialog.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/kicondialog.cpp b/src/kicondialog.cpp
index 85e923e..295fdb4 100644
--- a/src/kicondialog.cpp
+++ b/src/kicondialog.cpp
@@ -86,7 +86,7 @@ KIconDialog::KIconDialog(TQWidget *parent, const char*)
d = new KIconDialogPrivate;
mpLoader = KGlobal::iconLoader();
init();
- resize(tqminimumSize());
+ resize(minimumSize());
}
KIconDialog::KIconDialog(KIconLoader *loader, TQWidget *parent,
@@ -256,7 +256,7 @@ void KIconDialog::setup(KIcon::Group group, KIcon::Context context,
d->extendedContext = static_cast<ExtendedContext>( ( context == KIcon::Any ) ? ALL : context + 1 );
- // We cannot change tqlayout because it is protected ;-(
+ // We cannot change layout because it is protected ;-(
// FIXME: TQt4 we will be able to inherit from both TQDialog and our GUI
d->ui->listBox->setEnabled(!lockContext);
d->ui->browseButton->setEnabled(!lockBrowse);
@@ -277,7 +277,7 @@ void KIconDialog::setCustomLocation( const TQString& location )
if (location.isEmpty())
{
- mFileList = KGlobal::dirs()->findAllResources("appicon", TQString::tqfromLatin1("*.png"));
+ mFileList = KGlobal::dirs()->findAllResources("appicon", TQString::fromLatin1("*.png"));
} else {
mFileList = mpLoader->queryIconsByDir(location);
}
@@ -304,7 +304,7 @@ void KIconDialog::showDialog()
{
d->custom = TQString();
// Make it so tqminimumSize returns correct value
d->ui->filterLabel->hide();
d->ui->searchLine->hide();
d->ui->progressBar->show();
@@ -313,7 +313,7 @@ void KIconDialog::showDialog()
show();
// FIXME: this should be before show() but it doesn't work ;-(
- resize(tqminimumSize());
+ resize(minimumSize());
showIcons();
}
@@ -304,7 +304,7 @@ void KIconDialog::showDialog()
{
d->custom = TQString();
- // Make it so tqminimumSize returns correct value
+ // Make it so minimumSize returns correct value
d->ui->filterLabel->hide();
d->ui->searchLine->hide();